<?php
/**
 * Admin
 *
 * @package GamiPress\BuddyPress_Group_Leaderboard\Admin
 * @since 1.0.0
 */

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Shortcut function to get plugin options
 *
 * @since  1.0.0
 *
 * @param string    $option_name
 * @param bool      $default
 *
 * @return mixed
 */
function gamipress_bp_group_leaderboard_get_option( $option_name, $default = false ) {

    $prefix = 'bp_group_leaderboard_';

    return gamipress_get_option( $prefix . $option_name, $default );
}

/**
 * Plugin Settings meta boxes
 *
 * @since  1.0.0
 *
 * @param array $meta_boxes
 *
 * @return array
 */
function gamipress_bp_group_leaderboard_settings_meta_boxes( $meta_boxes ) {

    $prefix = 'bp_group_leaderboard_';

    $meta_boxes['gamipress-buddypress-group-leaderboard-settings'] = array(
        'title' => __( 'BuddyPress Group Leaderboard', 'gamipress-buddypress-group-leaderboard' ),
        'fields' => apply_filters( 'gamipress_buddypress_group_leaderboard_settings_fields', array(
            $prefix . 'tab_title' => array(
                'name' 	=> __( 'Group leaderboard tab title', 'gamipress-buddypress-group-leaderboard' ),
                'desc' 	=> __( 'Text to show on the BuddyPress group page.', 'gamipress-buddypress-group-leaderboard' ),
                'type' 	=> 'text',
                'default' => __( 'Leaderboard', 'gamipress-buddypress-group-leaderboard' ),
            ),
            $prefix . 'metrics' => array(
                'name' 	=> __( 'Metrics to track', 'gamipress-buddypress-group-leaderboard' ),
                'desc' 	=> __( 'Choose the metrics with which group leaderboards will be ranked.', 'gamipress-buddypress-group-leaderboard' ),
                'type' 	=> 'multicheck',
                'options' 	=> 'gamipress_leaderboards_metrics_options_cb', // Callback from Leaderboards add-on
                'classes' 	=> 'gamipress-switch',
            ),
            // Need to set it as text and hide the field because CMB2 moves hidden fields to the end of the form
            $prefix . 'columns_order' => array(
                'name' 	        => __( 'Columns Order', 'gamipress-buddypress-group-leaderboard' ),
                'type' 	        => 'text',
                'attributes' 	=> array( 'type' => 'hidden' ),
            ),
            $prefix . 'columns' => array(
                'name' 	        => __( 'Columns', 'gamipress-buddypress-group-leaderboard' ),
                'desc' 	        => __( 'Choose the columns to show. Drag and drop any option to reorder them.', 'gamipress-buddypress-group-leaderboard' ),
                'type' 	        => 'multicheck',
                'options_cb' 	=> 'gamipress_bp_group_leaderboard_columns_options_cb',
                'classes' 	    => 'gamipress-switch',
            ),
            $prefix . 'avatar_size' => array(
                'name' 	        => __( 'Avatar Size', 'gamipress-buddypress-group-leaderboard' ),
                'desc' 	        => __( 'Size of the users avatars.', 'gamipress-buddypress-group-leaderboard' ),
                'type' 	        => 'text',
                'attributes' 	=> array(
                    'type' => 'number',
                    'pattern' => '\d*',
                ),
                'default'    => 96,
            ),
            $prefix . 'search' => array(
                'name' 	        => __( 'Show Search', 'gamipress-buddypress-group-leaderboard' ),
                'desc' 	        => __( 'Display a search input.', 'gamipress-buddypress-group-leaderboard' ),
                'type' 	        => 'checkbox',
                'classes' 	    => 'gamipress-switch',
            ),
            $prefix . 'sort' => array(
                'name' 	        => __( 'Enable Sort', 'gamipress-buddypress-group-leaderboard' ),
                'desc' 	        => __( 'Enable live column sorting.', 'gamipress-buddypress-group-leaderboard' ),
                'type' 	        => 'checkbox',
                'classes'       => 'gamipress-switch',
            ),
            $prefix . 'hide_admins' => array(
                'name' 	        => __( 'Hide Administrators', 'gamipress-buddypress-group-leaderboard' ),
                'desc' 	        => __( 'Hide website administrators.', 'gamipress-buddypress-group-leaderboard' ),
                'type' 	        => 'checkbox',
                'classes'       => 'gamipress-switch',
            ),
        ) )
    );

    return $meta_boxes;

}
add_filter( 'gamipress_settings_addons_meta_boxes', 'gamipress_bp_group_leaderboard_settings_meta_boxes' );

/**
 * Plugin automatic updates
 *
 * @since  1.0.0
 *
 * @param array $automatic_updates_plugins
 *
 * @return array
 */
function gamipress_bp_group_leaderboard_automatic_updates( $automatic_updates_plugins ) {

    $automatic_updates_plugins['gamipress-buddypress-group-leaderboard'] = __( 'BuddyPress Group Leaderboard', 'gamipress-buddypress-group-leaderboard' );

    return $automatic_updates_plugins;

}
add_filter( 'gamipress_automatic_updates_plugins', 'gamipress_bp_group_leaderboard_automatic_updates' );

// Columns options cb
function gamipress_bp_group_leaderboard_columns_options_cb( $field ) {

    $columns_order = gamipress_bp_group_leaderboard_get_option( 'columns_order', false );

    if( ! $columns_order ) {
        $columns_order = array();
    }

    $columns_options = gamipress_leaderboards_get_columns_options();

    $final_options = array();

    foreach( $columns_order as $column_option ) {
        if( isset( $columns_options[$column_option] ) ) {
            $final_options[$column_option] = '<input type="hidden" name="gamipress_bp_group_leaderboard_columns_order[]" value="' . $column_option . '" />' .  $columns_options[$column_option];
        }
    }

    $columns_options_keys = array_keys( $columns_options );
    $unordered_column_options = array_diff( $columns_options_keys, $columns_order );

    // Append unordered column options
    foreach( $unordered_column_options as $column_option ) {
        if( isset( $columns_options[$column_option] ) ) {
            $final_options[$column_option] = '<input type="hidden" name="gamipress_bp_group_leaderboard_columns_order[]" value="' . $column_option . '" />' .  $columns_options[$column_option];
        }
    }

    return $final_options;

}
