<?php
/**
 * Content Filters
 *
 * @package GamiPress\BuddyPress_Group_Leaderboard\Content_Filters
 * @since 1.0.0
 */

// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Filter leaderboard query vars to just include group members
 *
 * @param array     $query_vars
 * @param int       $leaderboard_id
 *
 * @return array
 */
function gamipress_bp_group_leaderboard_leaderboard_pre_query_vars( $query_vars, $leaderboard_id ) {

    // Check if leaderboard is for a specific group
    $group_id = absint( gamipress_get_post_meta( $leaderboard_id, '_gamipress_bp_group_leaderboard_group_id' ) );

    if( $group_id !== 0 ) {

        // Get all group members
        $group_members = groups_get_group_members( array(
            'group_id' => $group_id,
            'per_page' => -1,
            'exclude_admins_mods' => false
        ) );

        // Setup an array of group members IDs to be used on $query_vars
        $include_users = array();

        if( $group_members && isset( $group_members['members'] ) && ! empty( $group_members['members'] ) ) {

            foreach( $group_members['members'] as $group_member ) {

                $include_users[] = $group_member->ID;
            }

        }

        // Force leaderboards users to just group members
        $query_vars['where'][] = "u.ID IN ( " . implode( ', ', $include_users ) . " )";

    }

    return $query_vars;

}
add_filter( 'gamipress_leaderboards_leaderboard_pre_query_vars', 'gamipress_bp_group_leaderboard_leaderboard_pre_query_vars', 10, 2 );

/**
 * Filter leaderboard columns to show
 *
 * @param array     $columns
 * @param int       $leaderboard_id
 *
 * @return array
 */
function gamipress_bp_group_leaderboard_leaderboard_columns( $columns, $leaderboard_id ) {

    // Backward compatibility
    if( is_object($leaderboard_id) ) {
        $leaderboard_id = $leaderboard_id->leaderboard_id;
    }

    // Check if leaderboard is for a specific group
    $group_id = absint( gamipress_get_post_meta( $leaderboard_id, '_gamipress_bp_group_leaderboard_group_id' ) );

    if( $group_id !== 0 ) {

        $columns = gamipress_bp_group_leaderboard_get_option( 'columns', array() );

    }

    return $columns;

}
add_filter( 'gamipress_leaderboards_leaderboard_columns', 'gamipress_bp_group_leaderboard_leaderboard_columns', 10, 2 );

/**
 * Filter leaderboard metrics to track
 *
 * @param array     $metrics
 * @param int       $leaderboard_id
 *
 * @return array
 */
function gamipress_bp_group_leaderboard_leaderboard_metrics( $metrics, $leaderboard_id ) {

    // Backward compatibility
    if( is_object($leaderboard_id) ) {
        $leaderboard_id = $leaderboard_id->leaderboard_id;
    }

    // Check if leaderboard is for a specific group
    $group_id = absint( gamipress_get_post_meta( $leaderboard_id, '_gamipress_bp_group_leaderboard_group_id' ) );

    if( $group_id !== 0 ) {

        $metrics = gamipress_bp_group_leaderboard_get_option( 'metrics', array() );

    }

    return $metrics;

}
add_filter( 'gamipress_leaderboards_leaderboard_metrics', 'gamipress_bp_group_leaderboard_leaderboard_metrics', 10, 2 );